@@ -310,11 +310,6 @@ package Sidef::Types::Block::Block {
         }
     }
 
-    {
-        no strict 'refs';
-        *{__PACKAGE__ . '::' . '*'} = \&repeat;
-    }
-
     sub capture {
         my ($self) = @_;
 
@@ -377,28 +372,11 @@ package Sidef::Types::Block::Block {
         my $ref = ref($obj);
 
         if ($ref eq 'Sidef::Types::Number::Number') {
-            my ($code, $value) = $obj->_deparse();
-
-            $code < 0  && return scalar {dump => ($ref . "->_set_int('$value')")};
-            $code <= 1 && return scalar {dump => ($ref . "->_set_uint('$value')")};
-
-            return scalar {dump => ($ref . "->_set_str('$value')"),};
-        }
-        elsif ($ref eq 'Sidef::Types::Number::Complex') {
-            my ($re, $im) = $obj->reals();
-            return scalar {dump => $ref . "->new('$re', '$im')",};
-        }
-        elsif ($ref eq 'Sidef::Types::Number::Inf') {
-            return scalar {dump => "$ref->new",};
-        }
-        elsif ($ref eq 'Sidef::Types::Number::Ninf') {
-            return scalar {dump => "$ref->new",};
-        }
-        elsif ($ref eq 'Sidef::Types::Number::Nan') {
-            return scalar {dump => "$ref->new",};
+            my ($type, $str) = $obj->_dump();
+            return scalar {dump => ($ref . "->_set_str('$type', '$str')"),};
         }
         elsif ($ref eq 'Sidef::Types::Block::Block') {
-            die "[ERROR] Blocks can't be serialized by Block.ffork()!";
+            die "[ERROR] Blocks cannot be serialized by Block.ffork()!";
         }
 
         return;
@@ -464,25 +442,117 @@ package Sidef::Types::Block::Block {
     *thr = \&thread;
 
     sub for {
-        my ($self, @args) = @_;
+        my ($self, @objs) = @_;
 
-        if (@args == 1 and defined(UNIVERSAL::can($args[0], 'each'))) {
-            $args[0]->each($self);
-        }
-        else {
-            my $code = $self->{code};
-            foreach my $item (@args) {
-                $code->($item);
+        my $block = $self->{code};
+
+        foreach my $obj (@objs) {
+            if (defined(my $sub = UNIVERSAL::can($obj, 'iter'))) {
+                my $iter  = $sub->($obj);
+                my $break = 0;
+                while (1) {
+                    $break = 1;
+                    $block->(
+                             $iter->run // do { $break = 0; last }
+                            );
+                    $break = 0;
+                }
+                last if $break;
+            }
+            else {
+                my $break = 0;
+                foreach my $item (UNIVERSAL::isa($obj, 'ARRAY') ? @$obj : @{$obj->to_a}) {
+                    $break = 1;
+                    $block->($item);
+                    $break = 0;
+                }
+                last if $break;
             }
-            $self;
         }
+
+        $self;
     }
 
+    *each    = \&for;
     *foreach = \&for;
 
+    sub map {
+        my ($self, @objs) = @_;
+
+        my @array;
+        my $block = $self->{code};
+
+        foreach my $obj (@objs) {
+            if (defined(my $sub = UNIVERSAL::can($obj, 'iter'))) {
+                my $iter  = $sub->($obj);
+                my $break = 0;
+                while (1) {
+                    $break = 1;
+                    push @array, $block->(
+                                          $iter->run // do { $break = 0; last }
+                                         );
+                    $break = 0;
+                }
+                last if $break;
+            }
+            else {
+                my $break = 0;
+                foreach my $item (UNIVERSAL::isa($obj, 'ARRAY') ? @$obj : @{$obj->to_a}) {
+                    $break = 1;
+                    push @array, $block->($item);
+                    $break = 0;
+                }
+                last if $break;
+            }
+        }
+
+        Sidef::Types::Array::Array->new(\@array);
+    }
+
+    sub grep {
+        my ($self, @objs) = @_;
+
+        my @array;
+        my $block = $self->{code};
+
+        foreach my $obj (@objs) {
+            if (defined(my $sub = UNIVERSAL::can($obj, 'iter'))) {
+                my $iter  = $sub->($obj);
+                my $break = 0;
+                my $item;
+                while (1) {
+                    $break = 1;
+                    $item = $iter->run // do { $break = 0; last };
+                    push(@array, $item) if $block->($item);
+                    $break = 0;
+                }
+                last if $break;
+            }
+            else {
+                my $break = 0;
+                foreach my $item (UNIVERSAL::isa($obj, 'ARRAY') ? @$obj : @{$obj->to_a}) {
+                    $break = 1;
+                    push(@array, $item) if $block->($item);
+                    $break = 0;
+                }
+                last if $break;
+            }
+        }
+
+        Sidef::Types::Array::Array->new(\@array);
+    }
+
     sub dump {
         Sidef::Types::String::String->new("$_[0]");
     }
+
+    {
+        no strict 'refs';
+        *{__PACKAGE__ . '::' . '*'}  = \&repeat;
+        *{__PACKAGE__ . '::' . '<<'} = \&for;
+        *{__PACKAGE__ . '::' . '>>'} = \&map;
+        *{__PACKAGE__ . '::' . '&'}  = \&grep;
+    }
 }
 
 1;
